@@ -52,7 +52,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 221
+#define gmic_version 222
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -149,12 +149,6 @@ namespace cimg_library {
 
 #else // #ifndef gmic_build
 
-#ifdef __GNUC__
-#if defined(__FAST_MATH__)
-#error Using the -ffast-math CFLAG is known to lead to important issues in libgmic. Please disable it to compile.
-#endif
-#endif
-
 // Define private functions, used to compile libgmic.
 //---------------------------------------------------
 
@@ -386,6 +380,7 @@ struct gmic {
   static gmic_image<int> builtin_commands_inds;
   static gmic_image<char> stdlib;
   static gmic_list<void*> list_p_is_abort;
+  static bool is_display_available;
 
   gmic_list<char> *const commands, *const commands_names, *const commands_has_arguments,
     *const _variables, *const _variables_names, **const variables, **const variables_names,
